@@ -130,7 +130,8 @@ class Operator:
                         grounded_signature[parameter_name] = lifted_function.signature[parameter_name]
 
                     else:
-                        grounded_signature[lifted_function_params[index]] = lifted_function.signature[parameter_name]
+                        grounded_signature[parameters_map[lifted_function_params[index]]] = \
+                            lifted_function.signature[parameter_name]
 
                 grounded_function = PDDLFunction(name=lifted_function.name,
                                                  signature=grounded_signature)
